@@ -4,9 +4,8 @@ from zeep import Client
 from zeep.transports import Transport
 import xml.etree.ElementTree as ET
 from dateutil import relativedelta
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 from math import ceil
-from .utils import *
 
 
 class IP21Connector(object):
@@ -21,26 +20,40 @@ class IP21Connector(object):
         session.auth = HTTPBasicAuth(self.user, self.pw)
         url = 'http://' + self.server + '/SQLPlusWebService/SQLPlusWebService.asmx'
         self.client = Client(url + '?WSDL', transport=Transport(session=session))
-
+    
     @staticmethod
-    def time_ranges(stop_time, end_time=datetime.now(), interval=800):
-        ranges_list = []
-        while stop_time < end_time:
-            start_time = end_time - relativedelta.relativedelta(hours=interval)
-            ranges = {'start': start_time, 'end': end_time}
-            ranges_list.append(ranges)
-            end_time = start_time
-        return ranges_list
+    def remove_timezone(dt):
+        if dt.tzinfo is not None and dt.tzinfo.utcoffset(dt) is not None:
+            dt = dt.replace(tzinfo=None)
+        return dt
+    
+    @staticmethod
+    def convert_to_aspen_dt(pydt):
+        return pydt.strftime('%d-%b-%y %H:%M:%S').upper()
+    
+    @staticmethod
+    def calculate_points_in_time_range(start_time, end_time, period):
+        period_in_seconds = (datetime.strptime(period, '%H:%M:%S') - datetime(1900, 1, 1)).total_seconds()
+        return ceil((end_time - start_time).total_seconds() / period_in_seconds)
+    
+    @staticmethod
+    def parse_xml(root):
+        all_records = []
+        for i, child in enumerate(root):
+            record = {}
+            for sub_child in child:
+                record[sub_child.tag] = sub_child.text
+            all_records.append(record)
+        return all_records
 
-    def history(self, start_time, end_time, tag_name, request=1, period='00:05:00', stepped=0):
+    def history(self, start_time, end_time, tag_name, request=1, period='00:05:00', stepped=0, pull_limit=20000):
 
         parsed_data = []
 
-        pull_limit = 20000
+        start_time = self.remove_timezone(start_time)
+        end_time = self.remove_timezone(end_time)
 
-        period_in_seconds = (datetime.strptime(period, '%H:%M:%S') - datetime(1900, 1, 1)).total_seconds()
-        total_seconds = (end_time - start_time).total_seconds()
-        num_points = ceil(total_seconds / period_in_seconds)
+        num_points = self.calculate_points_in_time_range(start_time, end_time, period)
 
         if num_points >= pull_limit:
 
@@ -58,15 +71,15 @@ class IP21Connector(object):
                         AND stepped={stepped}
                     """.format(
                             tag_name=tag_name,
-                            start_time=py_to_aspen_dt(update_start_time),
-                            end_time=py_to_aspen_dt(update_end_time),
+                            start_time=self.convert_to_aspen_dt(update_start_time),
+                            end_time=self.convert_to_aspen_dt(update_end_time),
                             period=period,
                             request=request,
                             stepped=stepped)
 
                 result = self.client.service.ExecuteSQL(sql)
 
-                for data_point in parse_xml(ET.fromstring(result)):
+                for data_point in self.parse_xml(ET.fromstring(result)):
                     parsed_data.append(data_point)
 
                 update_start_time = update_end_time
@@ -79,26 +92,26 @@ class IP21Connector(object):
                     BETWEEN '{start_time}' AND '{end_time}'  AND request={request} AND period={period}
                 """.format(
                 tag_name=tag_name,
-                start_time=py_to_aspen_dt(start_time),
-                end_time=py_to_aspen_dt(end_time),
+                start_time=self.convert_to_aspen_dt(start_time),
+                end_time=self.convert_to_aspen_dt(end_time),
                 period=period,
                 request=request)
 
             result = self.client.service.ExecuteSQL(sql)
 
-            parsed_data = parse_xml(ET.fromstring(result))
+            parsed_data = self.parse_xml(ET.fromstring(result))
 
         return parsed_data
 
     def get_value(self, name, timestamp=datetime.now()):
-        timestamp = py_to_aspen_dt(timestamp)
+        timestamp = self.convert_to_aspen_dt(timestamp)
 
         sql = """SELECT ISO8601(ts) AS "utc_time", value FROM history WHERE name='{name}' 
             AND ts='{timestamp}' AND request=2""".format(name=name, timestamp=timestamp)
 
         result = self.client.service.ExecuteSQL(sql)
         root = ET.fromstring(result)
-        return parse_xml(root)
+        return self.parse_xml(root)
 
     def get_last_actual_value(self, name):
 
@@ -108,7 +121,7 @@ class IP21Connector(object):
 
         result = self.client.service.ExecuteSQL(sql)
         root = ET.fromstring(result)
-        return parse_xml(root)
+        return self.parse_xml(root)
 
     def get_all_tag_definitions(self):
         sql = """SELECT
@@ -146,7 +159,7 @@ class IP21Connector(object):
 
         result = self.client.service.ExecuteSQL(sql)
         root = ET.fromstring(result)
-        return parse_xml(root)
+        return self.parse_xml(root)
 
     def tags_list(self, tags):
 
@@ -189,4 +202,4 @@ class IP21Connector(object):
 
         result = self.client.service.ExecuteSQL(sql)
         root = ET.fromstring(result)
-        return parse_xml(root)
\ No newline at end of file
+        return self.parse_xml(root)
\ No newline at end of file
